@@ -18,17 +18,17 @@ class Atig::Agent::ListStatus
       db.lists.each do |name, _|
         log :debug, "retrieve #{name} statuses"
         q = {}
-        q.update(:since_id => @prev[name]) if @prev.key?(name)
+        q.update(since_id: @prev[name]) if @prev.key?(name)
 
         screen_name, slug = parse name
-        q.update(:owner_screen_name => screen_name, :slug => slug)
+        q.update(owner_screen_name: screen_name, slug: slug)
         statuses = t.get("lists/statuses", q)
         statuses.reverse_each do|status|
           db.statuses.transaction do|d|
-            d.add(:status => status,
-                  :user => status.user,
-                  :source => :list,
-                  :list => name)
+            d.add(status: status,
+                  user: status.user,
+                  source: :list,
+                  list: name)
           end
         end
         @prev[name] = statuses[0].id if statuses && statuses.size > 0
