@@ -20,8 +20,8 @@ module Atig
         text = mesg.split(" ", 3)[2]
         api.delay(0) do|t|
           t.post("direct_messages/new",{
-                   :screen_name => user,
-                   :text => text
+                   screen_name: user,
+                   text: text
                  })
           yield "Sent message to #{user}: #{text}"
         end
