@@ -3,7 +3,7 @@
 module Atig
   module UpdateChecker
     def commits
-      uri = URI("https://api.github.com/repos/mzp/atig/commits")
+      uri = URI("https://api.github.com/repos/atig/atig/commits")
       http = Atig::Http.new
       res = http.http(uri).request http.req(:get, uri)
       JSON.parse(res.body)
@@ -47,7 +47,7 @@ module Atig
           end.map {|i| i['commit']['message'] }
         end
       end
-    rescue Errno::ECONNREFUSED, Timeout::Error => e
+    rescue TypeError, Errno::ECONNREFUSED, Timeout::Error
       []
     end
 
