@@ -1,6 +1,5 @@
 # -*- mode:ruby; coding:utf-8 -*-
 
-require File.expand_path( '../../spec_helper', __FILE__ )
 require 'atig/command/name'
 
 describe Atig::Command::Name do
@@ -11,8 +10,8 @@ describe Atig::Command::Name do
   end
 
   it "should update name" do
-    @api.should_receive(:post).with('account/update_profile',:name=>'mzp')
-    @channel.should_receive(:notify).with("You are named mzp.")
+    expect(@api).to receive(:post).with('account/update_profile',:name=>'mzp')
+    expect(@channel).to receive(:notify).with("You are named mzp.")
     call '#twitter', 'name', %w(mzp)
   end
 end
