@@ -1,6 +1,5 @@
 # -*- mode:ruby; coding:utf-8 -*-
 
-require File.expand_path( '../../spec_helper', __FILE__ )
 require 'atig/command/refresh'
 require 'atig/command/info'
 
@@ -12,9 +11,9 @@ describe Atig::Command::Refresh do
   end
 
   it "should refresh all" do
-    @followings.should_receive(:invalidate)
-    @lists.should_receive(:invalidate).with(:all)
-    @channel.should_receive(:notify).with("refresh followings/lists...")
+    expect(@followings).to receive(:invalidate)
+    expect(@lists).to receive(:invalidate).with(:all)
+    expect(@channel).to receive(:notify).with("refresh followings/lists...")
 
     call '#twitter','refresh', []
   end
