@@ -1,6 +1,5 @@
 # -*- mode:ruby; coding:utf-8 -*-
 
-require File.expand_path( '../../spec_helper', __FILE__ )
 require 'atig/db/listenable'
 
 class SampleListener
@@ -24,9 +23,9 @@ describe Atig::Db::Listenable, "when it is called" do
   it "should call all listener" do
     @listeners.hi 1,2,3
 
-    @args.length.should == 3
+    expect(@args.length).to eq(3)
     1.upto(2) {|i|
-      @args[i].should == [1,2,3]
+      expect(@args[i]).to eq([1,2,3])
     }
   end
 end
